.. _cluster:

cluster
=======

This module initializes the cluster functions of the hsi-wizard package.

Module Overview
---------------

.. currentmodule:: wizard._processing.cluster

Functions
---------

.. autofunction:: quit_low_change_in_clusters
.. autofunction:: discard_clusters
.. autofunction:: update_clusters
.. autofunction:: initial_clusters
.. autofunction:: sort_arrays_by_first
.. autofunction:: split_clusters
.. autofunction:: compute_avg_distance
.. autofunction:: compute_overall_distance
.. autofunction:: merge_clusters
.. autofunction:: compute_pairwise_distances
.. autofunction:: isodata

Credits
-------
The Isodata code was inspired by:
 Repository: pyRadar
 Author/Organization: PyRadar
 Original repository: https://github.com/PyRadar/pyradar/